@@ -30,23 +30,23 @@
 #' latent groups with unique success probabilities on item \eqn{j}, where
 #' \eqn{K_j^*=\sum_{k=1}^{K}q_{jk}}.
 #'
-#' Let \eqn{\mathbf{\alpha}_{lj}^*} be the reduced attribute
+#' Let \eqn{\boldsymbol{\alpha}_{lj}^*} be the reduced attribute
 #' pattern consisting of the columns of the attributes required by item \eqn{j}, where
 #' \eqn{l=1,\ldots,2^{K_j^*}}. For example, if only the first and the last attributes are
-#' required, \eqn{\mathbf{\alpha}_{lj}^*=(\alpha_{l1},\alpha_{lK})}. For notational
+#' required, \eqn{\boldsymbol{\alpha}_{lj}^*=(\alpha_{l1},\alpha_{lK})}. For notational
 #' convenience, the first \eqn{K_j^*} attributes can be assumed to be the required attributes
-#' for item \eqn{j} as in de la Torre (2011). The probability of success \eqn{P(X_{j}=1|\mathbf{\alpha}_{lj}^*)} is denoted
-#' by \eqn{P(\mathbf{\alpha}_{lj}^*)}. To model this probability of success, different link functions
+#' for item \eqn{j} as in de la Torre (2011). The probability of success \eqn{P(X_{j}=1|\boldsymbol{\alpha}_{lj}^*)} is denoted
+#' by \eqn{P(\boldsymbol{\alpha}_{lj}^*)}. To model this probability of success, different link functions
 #' as in the generalized linear models are used in the G-DINA model. The item response
 #' function of the G-DINA model using the identity link can be written as
 #' \deqn{
-#' f[P(\mathbf{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}+
+#' f[P(\boldsymbol{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}+
 #' \sum_{k'=k+1}^{K_j^*}\sum_{k=1}^{K_j^*-1}\delta_{jkk'}\alpha_{lk}\alpha_{lk'}+\cdots+
 #' \delta_{j12{\cdots}K_j^*}\prod_{k=1}^{K_j^*}\alpha_{lk},
 #' }
 #' or in matrix form,
 #' \deqn{
-#' f[\mathbf{P}_j]=\mathbf{M}_j\mathbf{\delta}_j,
+#' f[\boldsymbol{P}_j]=\boldsymbol{M}_j\boldsymbol{\delta}_j,
 #' }
 #' where \eqn{\delta_{j0}} is the intercept for item \eqn{j}, \eqn{\delta_{jk}} is the main effect
 #' due to \eqn{\alpha_{lk}}, \eqn{\delta_{jkk'}} is the interaction effect due to
@@ -74,31 +74,51 @@
 #'        To obtain the DINA model from the G-DINA model,
 #'        all terms in identity link G-DINA model except \eqn{\delta_0} and \eqn{\delta_{12{\ldots}K_j^*}}
 #'        need to be fixed to zero, that is,
-#'        \deqn{ P(\mathbf{\alpha}_{lj}^*)=\delta_{j0}+\delta_{j12{\cdots}K_j^*}\prod_{k=1}^{K_j^*}\alpha_{lk}}
+#'        \deqn{P(\boldsymbol{\alpha}_{lj}^*)=
+#'        \delta_{j0}+\delta_{j12{\cdots}K_j^*}\prod_{k=1}^{K_j^*}\alpha_{lk}}
 #'        In this parameterization, \eqn{\delta_{j0}=g_j} and \eqn{\delta_{j0}+\delta_{j12{\cdots}K_j^*}=1-s_j}.
-#'
 #'    }
 #' \item{\code{DINO model}}{
 #'        The DINO model can be given by
-#'        \deqn{P(\mathbf{\alpha}_{lj}^*)=\delta_{j0}+\delta_{j1}I(\mathbf{\alpha}_{lj}^*\neq \mathbf{0})}
+#'        \deqn{P(\boldsymbol{\alpha}_{lj}^{*})=
+#'        \delta_{j0}+\delta_{j1}I(\boldsymbol{\alpha}_{lj}^*\neq \boldsymbol{0})}
 #'
 #'        where \eqn{I(\cdot)} is an indicator variable. The DINO model is also a constrained identity
 #'        link G-DINA model. As shown by de la Torre (2011), the appropriate constraint is
 #'        \deqn{\delta_{jk}=-\delta_{jk^{'}k^{''}}=\cdots=(-1)^{K_j^*+1}\delta_{j12{\cdots}K_j^*},} for
-#'        \eqn{k=1,\cdots,K_j^*, k^{'}=1,\cdots,K_j^*-1$, and $k^{''}>k^{'},\cdots,K_j^*}.
+#'        \eqn{k=1,\cdots,K_j^*, k^{'}=1,\cdots,K_j^*-1}, and \eqn{k^{''}>k^{'},\cdots,K_j^*}.
 #'    }
 #' \item{\code{Additive models with different link functions}}{
 #'        The A-CDM, LLM and R-RUM can be obtained by setting all interactions to be zero in
 #'        identity, logit and log link G-DINA model, respectively. Specifically, the A-CDM can be formulated as
-#'        \deqn{P(\mathbf{\alpha}_{lj}^*)=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}.}
+#'        \deqn{P(\boldsymbol{\alpha}_{lj}^*)=
+#'        \delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}}
 #'        The item response function for
 #'        LLM can be given by
-#'        \deqn{ logit[P(\mathbf{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk},}
+#'        \deqn{ logit[P(\boldsymbol{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk},}
 #'        and lastly, the RRUM, can be written as
-#'        \deqn{log[P(\mathbf{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}.} It should be
+#'        \deqn{log[P(\boldsymbol{\alpha}_{lj}^*)]=\delta_{j0}+\sum_{k=1}^{K_j^*}\delta_{jk}\alpha_{lk}.} It should be
 #'        noted that the LLM is equivalent to the compensatory RUM, which is subsumed by the GDM, and that
 #'        the RRUM is a special case of the generalized noisy inputs, deterministic ``And" gate model (G-NIDA).
 #'    }
+#' \item{\code{Simultaneously identifying skills and misconceptions (SISM)}}{
+#'        The SISM can be can be reformulated as
+#'        \deqn{P(\boldsymbol{\alpha}_{lj}^*)=
+#'        \delta_{j0}+\delta_{j1}I[{mastering all skills}]+
+#'        \delta_{j2}I[{having no bugs}]+\delta_{j12}I[{mastering all skills and having no bugs}].}
+#'        As a result,the success probability of students who have mastered all the measured skills and possess
+#'        none of the measured misconceptions (\eqn{h_j} in Equation 4 of Kuo, et al, 2018) is
+#'        \eqn{\delta_{j0}+\delta_{j1}+\delta_{j2}+\delta_{j12}}, the success probability of students who have
+#'        mastered all the measured skills but possess some of the measured misconceptions (\eqn{\omega_j})
+#'          is \eqn{\delta_{j0}+\delta_{j1}}, the success probability of students who have not mastered all the
+#'          measured skills and possess none of the measured misconceptions (\eqn{g_j}) is
+#'          \eqn{\delta_{j0}+\delta_{j2}} and success probability of students who have not mastered all the
+#'          measured skills and possess at least one of the measured misconceptions(\eqn{\epsilon_j}) is
+#'          \eqn{\delta_{j0}}.
+#'
+#'          By specifying \code{no.bugs} being equal to the number of attributes, the Bug-DINO is obtained, as in
+#'          \deqn{P(\boldsymbol{\alpha}_{lj}^*)=\delta_{j0}+\delta_{j1}I[{having no bugs}].}
+#'    }
 #'    }
 #'
 #' @section Joint Attribute Distribution:
@@ -106,19 +126,18 @@
 #' The joint attribute distribution can be modeled using various methods. This section mainly focuses on the so-called
 #' higher-order approach, which was originally proposed by de la Torre
 #' and Douglas (2004) for the DINA model. It has been extended in this package for all condensation rules.
-#' Particularly, three IRT models are available for the higher-order attribute structure:
-#' Rasch model (Rasch), one parameter logistic model (1PL) and two parameter logistic model (2PL).
-#' For the Rasch model, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
+#' Particularly, three approaches are available for the higher-order attribute structure:
+#' intercept only approach, common slope approach and varied slope approach.
+#' For the intercept only approach, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
 #' \deqn{P(\alpha_k=1|\theta_i,\lambda_{0k})=\frac{exp(\theta_i+\lambda_{0k})}{1+exp(\theta_i+\lambda_{0k})}}
-#' For the 1PL model, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
+#' For the common slope approach, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
 #' \deqn{P(\alpha_k=1|\theta_i,\lambda_{0k},\lambda_{1})=\frac{exp(\lambda_{1}\theta_i+\lambda_{0k})}{1+exp(\lambda_{1}\theta_i+\lambda_{0k})}}
-#' For the 2PL model, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
+#' For the varied slope approach, the probability of mastering attribute \eqn{k} for individual \eqn{i} is defined as
 #' \deqn{P(\alpha_k=1|\theta_i,\lambda_{0k},\lambda_{1k})=\frac{exp(\lambda_{1k}\theta_i+\lambda_{0k})}{1+exp(\lambda_{1k}\theta_i+\lambda_{0k})}}
 #' where \eqn{\theta_i} is the ability of examinee \eqn{i}. \eqn{\lambda_{0k}} and \eqn{\lambda_{1k}} are the intercept
-#' and slope parameters for attribute \eqn{k}, respectively. In the Rasch model, \eqn{\lambda_{1k}=1 \forall k};
-#' whereas in the 1PL model, a common slope parameter \eqn{\lambda_{1}} is estimated.
+#' and slope parameters for attribute \eqn{k}, respectively.
 #' The probability of joint attributes can be written as
-#'  \deqn{P(\mathbf{\alpha}|\theta_i,\mathbf{\lambda})=\prod_k P(\alpha_k|\theta_i,\mathbf{\lambda})}.
+#'  \deqn{P(\boldsymbol{\alpha}|\theta_i,\boldsymbol{\lambda})=\prod_k P(\alpha_k|\theta_i,\boldsymbol{\lambda})}.
 #'
 #'
 #'@section Model Estimation:
@@ -141,8 +160,7 @@
 #' if item \eqn{j} is ACDM, LLM or RRUM, it has \eqn{K_j^*+1} item parameters; if it is G-DINA model, it has \eqn{2^{K_j^*}} item parameters.
 #' Apart from item parameters, the parameters involved in the estimation of joint attribute distribution need to be estimated as well.
 #' When using the saturated attribute structure, there are \eqn{2^K-1} parameters for joint attribute distribution estimation; when
-#' using a higher-order attribute structure, there are \eqn{K}, \eqn{K+1}, and \eqn{2\times K} parameters for the Rasch model,
-#' 1PL model and 2PL model, respectively.
+#' using a higher-order attribute structure, there are \eqn{K}, \eqn{K+1}, and \eqn{2\times K} parameters for the intercept only approach, common slope approach and varied slope approach, respectively.
 #' For polytomous response data using the sequential G-DINA model, the number of item parameters
 #' are counted at category level.
 #'
@@ -159,10 +177,10 @@
 #'    of attributes are needed (see Chen, & de la Torre, 2013).  See \code{Examples}.
 #' @param model A vector for each item or nonzero category, or a scalar which will be used for all
 #'    items or nonzero categories to specify the CDMs fitted. The possible options
-#'    include \code{"GDINA"},\code{"DINA"},\code{"DINO"},\code{"ACDM"},\code{"LLM"}, \code{"RRUM"}, \code{"MSDINA"} and \code{"UDF"}. Note that
+#'    include \code{"GDINA"},\code{"DINA"},\code{"DINO"},\code{"ACDM"},\code{"LLM"}, \code{"RRUM"}, \code{"MSDINA"}, \code{"BUGDINO"}, \code{"SISM"}, and \code{"UDF"}. Note that
 #'    model can also be \code{"logitGDINA"} and \code{"logGDINA"}, indicating the saturated G-DINA model in logit and log link functions. They are
 #'    equivalent to the identity link saturated G-DINA model. The logit G-DINA model is identical to the log-linear CDM.
-#'    When \code{"UDF"}, indicating user defined function, is specified for any item, arguments \code{design.matrix} and \code{linkfunc} need to be defined.
+#'    When \code{"UDF"}, indicating user defined function, is specified for any item, arguments \code{design.matrix} and \code{linkfunc} need to be specified.
 #' @param sequential logical; \code{TRUE} if the sequential model is fitted for polytomous responses.
 #' @param group a factor or a vector indicating the group each individual belongs to. Its length must be equal to the number of individuals.
 #' @param att.dist How is the joint attribute distribution estimated? It can be (1) \code{saturated}, which is the default, indicating that
@@ -174,18 +192,15 @@
 #'    If different groups have different joint attribute distributions,
 #'    specify \code{att.dist} as a character vector with the same number of elements as the number of groups. However, if a higher-order model is used for any group,
 #'    it must be used for all groups.
-#' @param mono.constraint logical; \code{TRUE} indicates that \eqn{P(\mathbf{\alpha}_1) <=P(\mathbf{\alpha}_2)} if
+#' @param mono.constraint logical; \code{TRUE} indicates that \eqn{P(\boldsymbol{\alpha}_1) <=P(\boldsymbol{\alpha}_2)} if
 #'    for all \eqn{k}, \eqn{\alpha_{1k} < \alpha_{2k}}. Can be a vector for each item or nonzero category or a scalar which will be used for all
 #'    items to specify whether monotonicity constraint should be added.
 #' @param catprob.parm A list of initial success probability parameters for each nonzero category.
 #' @param item.names A vector giving the item names. By default, items are named as "Item 1", "Item 2", etc.
 #' @param higher.order A list specifying the higher-order joint attribute distribution with the following components:
 #'  \itemize{
-#'    \item \code{model} - a character indicating the IRT model for higher-order joint attribute distribution. Can be
-#'    \code{"2PL"}, \code{"1PL"} or \code{"Rasch"}, representing two parameter logistic IRT model,
-#'    one parameter logistic IRT model and Rasch model, respectively. For \code{"1PL"} model, a common slope parameter is
-#'    estimated. \code{"Rasch"} is the default model when \code{att.dist = "higher.order"}. Note that slope-intercept form
-#'    is used for parameterizing the higher-order IRT model (see \code{Details}).
+#'    \item \code{model} - a number indicating the model for higher-order joint attribute distribution. Can be
+#'    1, 2 or 3, representing the intercept only approach, common slope approach and varied slope approach (see \code{Details}).
 #'    \item \code{nquad} - a scalar specifying the number of integral nodes. Default = 25.
 #'    \item \code{SlopeRange} - a vector of length two specifying the range of slope parameters. Default = [0.1, 5].
 #'    \item \code{InterceptRange} - a vector of length two specifying the range of intercept parameters. Default = [-4, 4].
@@ -201,13 +216,14 @@
 #'    The sum of all elements does not have to be equal to 1; however, it will be normalized so that the sum is equal to 1
 #'    before calibration.
 #'    The label for each latent class can be obtained by calling \code{attributepattern(K)}. See \code{examples} for more info.
-#' @param latent.var A string indicating the nature of the latent variables. It is \code{"att"} (by default) if the latent variables are attributes,
-#'    and \code{"bugs"} if the latent variables are misconceptions. When \code{"bugs"} is specified, only the DINA, DINO or G-DINA model can be
-#'    specified in \code{model} argument (Kuo, Chen, Yang & Mok, 2016).
+#' @param no.bugs A numeric scalar (whole numbers only) indicating the number of bugs or misconceptions in the Q-matrix. The bugs must be included in the last \code{no.bugs} columns.
+#'    It can be used along with the \code{BUGDINO} and \code{SISM} models (see, Kuo, Chen, Yang & Mok, 2016; Kuo, Chen, & de la Torre, 2018). This argument will be ignored if the
+#'    model is not specified in \code{model} argument. Note that the \code{BUGDINO} and \code{SISM} models are reparametrized - see \code{Details} below. By default,
+#'    \code{no.bugs}=0, implying that there is no bugs/misconceptions.
 #' @param att.str Specify attribute structures. \code{NULL}, by default, means there is no structure. Attribute structure needs be specified as a list -
 #'    which will be internally handled by \code{att.structure} function. See examples. It can also be a matrix giving all permissible attribute profiles.
 #' @param loglinear the order of loglinear smooth for attribute space. It can be either 1 or 2 indicating the loglinear model with main effect only
-#'    and with main effect and first-order interaction.
+#'    and with main effect and first-order interaction; It can also be a matrix, representing the design matrix for the loglinear model.
 #' @param control A list of control parameters with elements:
 #' \itemize{
 #'      \item \code{maxitr} A vector for each item or nonzero category, or a scalar which will be used for all
@@ -293,6 +309,8 @@
 #' Junker, B. W., & Sijtsma, K. (2001). Cognitive assessment models with few assumptions, and connections with nonparametric
 #' item response theory. \emph{Applied Psychological Measurement, 25}, 258-272.
 #'
+#' Kuo, B.-C., Chen.-H., & de la Torre,J. (2018). A cognitive diagnosis model for identifying coexisting skills and misconceptions.\emph{Applied Psychological Measuremet}, 179–191.
+#'
 #' Ma, W., & de la Torre, J. (2016). A sequential cognitive diagnosis model for polytomous responses. \emph{British Journal of Mathematical and Statistical Psychology. 69,} 253-275.
 #'
 #' Ma, W., & de la Torre, J. (2020). GDINA: An R Package for Cognitive Diagnosis Modeling. \emph{Journal of Statistical Software, 93(14)}, 1-26.
@@ -314,6 +332,7 @@
 #' Xu, X., & von Davier, M. (2008). Fitting the structured general diagnostic model to NAEP data. ETS research report, RR-08-27.
 #'
 #' @importFrom Rcpp sourceCpp
+#' @importFrom nloptr nloptr slsqp nl.grad nl.jacobian
 #' @importFrom numDeriv hessian jacobian
 #' @importFrom alabama auglag
 #' @importFrom MASS ginv
@@ -748,46 +767,53 @@
 #'
 #' set.seed(123)
 #' Q <- sim10GDINA$simQ # 1 represents misconceptions/bugs
-#' ip <- list(
-#' c(0.8,0.2),
-#' c(0.7,0.1),
-#' c(0.9,0.2),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1),
-#' c(0.9,0.1,0.1,0.1,0.1,0.1,0.1,0.1))
-#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip,model = "DINO")
+#' N <- 1000
+#' J <- nrow(Q)
+#'
+#' gs <- data.frame(guess=rep(0.1,J),slip=rep(0.1,J))
+#'
+#' sim <- simGDINA(N,Q,gs.parm = gs,model = "BUGDINO")
 #' dat <- extract(sim,"dat")
-#' # use latent.var to specify a bug model
-#' est <- GDINA(dat=dat,Q=Q,latent.var="bugs",model="DINO")
+#' est <- GDINA(dat=dat,Q=Q,model = "BUGDINO")
 #' coef(est)
 #'
 #'####################################
 #'#           Example 12.            #
-#'#           Bug DINA model         #
+#'#           SISM model             #
 #'####################################
 #'
-#' set.seed(123)
-#' Q <- sim10GDINA$simQ # 1 represents misconceptions/bugs
-#' ip <- list(
-#' c(0.8,0.2),
-#' c(0.7,0.1),
-#' c(0.9,0.2),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.1),
-#' c(0.9,0.9,0.9,0.9,0.9,0.9,0.9,0.1))
-#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip,model="DINA")
+#' # The Q-matrix used in Kuo, et al (2018)
+#' # The first four columns are for Attributes 1-4
+#' # The last three columns are for Bugs 1-3
+#' Q <- matrix(c(1,0,0,0,0,0,0,
+#' 0,1,0,0,0,0,0,
+#' 0,0,1,0,0,0,0,
+#' 0,0,0,1,0,0,0,
+#' 0,0,0,0,1,0,0,
+#' 0,0,0,0,0,1,0,
+#' 0,0,0,0,0,0,1,
+#' 1,0,0,0,1,0,0,
+#' 0,1,0,0,1,0,0,
+#' 0,0,1,0,0,0,1,
+#' 0,0,0,1,0,1,0,
+#' 1,1,0,0,1,0,0,
+#' 1,0,1,0,0,0,1,
+#' 1,0,0,1,0,0,1,
+#' 0,1,1,0,0,0,1,
+#' 0,1,0,1,0,1,1,
+#' 0,0,1,1,0,1,1,
+#' 1,0,1,0,1,1,0,
+#' 1,1,0,1,1,1,0,
+#' 0,1,1,1,1,1,0),ncol = 7,byrow = TRUE)
+#'
+#' J <- nrow(Q)
+#' N <- 1000
+#' gs <- data.frame(guess=rep(0.1,J),slip=rep(0.1,J))
+#'
+#' sim <- simGDINA(N,Q,gs.parm = gs,model = "SISM",no.bugs=3)
 #' dat <- extract(sim,"dat")
-#' # use latent.var to specify a bug model
-#' est <- GDINA(dat=dat,Q=Q,latent.var="bugs",model="DINA")
-#' coef(est)
+#' est <- GDINA(dat=dat,Q=Q,model="SISM",no.bugs=3)
+#' coef(est,"delta")
 #'
 #'####################################
 #'#           Example 13a.           #
@@ -875,7 +901,7 @@
 GDINA <-
   function(dat, Q, model = "GDINA", sequential = FALSE, att.dist = "saturated", mono.constraint = FALSE,
            group = NULL,linkfunc = NULL, design.matrix = NULL,
-           latent.var = "att", att.prior = NULL, att.str = NULL, verbose = 1,
+           no.bugs = 0, att.prior = NULL, att.str = NULL, verbose = 1,
            higher.order = list(),loglinear = 2,catprob.parm = NULL,control=list(),
            item.names = NULL, solver = NULL,
            nloptr.args=list(),auglag.args=list(),solnp.args = list(),...)
@@ -901,7 +927,7 @@ GDINA <-
       ret <- SG.Est(dat = dat, Q = Q, model = model, sequential = sequential,
                     att.dist = att.dist, att.prior = att.prior,saturated=saturated,
                     att.str = att.str, mono.constraint=mono.constraint,
-                    latent.var = latent.var, verbose = verbose,
+                    no.bugs = no.bugs, verbose = verbose,
                     catprob.parm = catprob.parm,loglinear = loglinear,
                     item.names = item.names, control = control, item.prior = item.prior,
                     nloptr_args = nloptr.args,auglag_args=auglag.args,solnp_args = solnp.args,
@@ -911,7 +937,7 @@ GDINA <-
       ret <- MG.Est(dat = dat, Q = Q, model = model, sequential = sequential,
                     att.dist = att.dist, att.prior = att.prior,saturated=saturated,
                     att.str = att.str, mono.constraint=mono.constraint,
-                    group = group, latent.var=latent.var, verbose = verbose,
+                    group = group, no.bugs=no.bugs, verbose = verbose,
                     catprob.parm = catprob.parm,loglinear = loglinear,
                     item.names = item.names, control = control, item.prior = item.prior,
                     nloptr_args = nloptr.args,auglag_args=auglag.args,solnp_args = solnp.args,
@@ -925,3 +951,4 @@ GDINA <-
     class(ret) <- "GDINA"
     invisible(ret)
   }
+
