@@ -15,9 +15,9 @@ summary.GDINA <-
     "BIC penalty due to item parameters"=log(extract(object,"nobs"))*extract(object,"npar.item"),
     "BIC penalty due to population parameters"=log(extract(object,"nobs"))*extract(object,"npar.att"),
     "CAIC"=extract(object,"CAIC"),
-    "CAIC penalty"=log(extract(object,"nobs")+1)*extract(object,"npar"),
-    "CAIC penalty due to item parameters"=log(extract(object,"nobs")+1)*extract(object,"npar.item"),
-    "CAIC penalty due to population parameters"=log(extract(object,"nobs")+1)*extract(object,"npar.att"),
+    "CAIC penalty"=(log(extract(object,"nobs"))+1)*extract(object,"npar"),
+    "CAIC penalty due to item parameters"=(log(extract(object,"nobs"))+1)*extract(object,"npar.item"),
+    "CAIC penalty due to population parameters"=(log(extract(object,"nobs"))+1)*extract(object,"npar.att"),
     "SABIC"=extract(object,"SABIC"),
     "SABIC penalty"=log((extract(object,"nobs")+2)/24)*extract(object,"npar"),
     "SABIC penalty due to item parameters"=log((extract(object,"nobs")+2)/24)*extract(object,"npar.item"),
